@@ -1,10 +1,20 @@
-import os, sys
-from dotenv import load_dotenv
+import os, sys, pathlib
+from dotenv import dotenv_values
 
-load_dotenv()
+cwd_path = os.path.join(os.getcwd(), '.env')
+global_path = os.path.join(pathlib.Path.home(), '.config/tconnectsync/.env')
 
-def get(*args):
-    return os.environ.get(*args)
+values = {}
+
+if os.path.exists(cwd_path):
+    values = dotenv_values(cwd_path)
+elif os.path.exists(global_path):
+    values = dotenv_values(global_path)
+else:
+    values = dotenv_values()
+
+def get(val, default=None):
+    return os.environ.get(val, values.get(val, default))
 
 def get_number(name, default):
     val = get(name, default)
@@ -36,11 +46,8 @@ AUTOUPDATE_USE_FIXED_SLEEP = get_bool('AUTOUPDATE_USE_FIXED_SLEEP', 'false')
 AUTOUPDATE_FAILURE_MINUTES = get_number('AUTOUPDATE_FAILURE_MINUTES', '180') # 3 hours
 AUTOUPDATE_RESTART_ON_FAILURE = get_bool('AUTOUPDATE_RESTART_ON_FAILURE', 'false')
 
-_config = ['TCONNECT_EMAIL', 'TCONNECT_PASSWORD', 'PUMP_SERIAL_NUMBER',
-          'NS_URL', 'NS_SECRET', 'TIMEZONE_NAME',
-          'AUTOUPDATE_DEFAULT_SLEEP_SECONDS', 'AUTOUPDATE_MAX_SLEEP_SECONDS',
-          'AUTOUPDATE_USE_FIXED_SLEEP', 'AUTOUPDATE_FAILURE_MINUTES',
-          'AUTOUPDATE_RESTART_ON_FAILURE']
+ENABLE_TESTING_MODES = get_bool('ENABLE_TESTING_MODES', 'false')
+SKIP_NS_LAST_UPLOADED_CHECK = get_bool('SKIP_NS_LAST_UPLOADED_CHECK', 'false')
 
 if __name__ == '__main__':
     for k in locals():
